@@ -292,7 +292,7 @@ public class EclipseMenuItemUI extends MenuItemUI {
         return new PropertyChangeHandler();
     }
 
-    ActionMap getActionMap() {
+    protected ActionMap getActionMap() {
         String propertyPrefix = getPropertyPrefix();
         String uiKey = propertyPrefix + ".actionMap";
         ActionMap am = (ActionMap) UIDefaultsLookup.get(uiKey);
@@ -303,7 +303,7 @@ public class EclipseMenuItemUI extends MenuItemUI {
         return am;
     }
 
-    ActionMap createActionMap() {
+    protected ActionMap createActionMap() {
         ActionMap map = new ActionMapUIResource();
         map.put("doClick", new ClickAction());
 
@@ -316,7 +316,7 @@ public class EclipseMenuItemUI extends MenuItemUI {
         return map;
     }
 
-    InputMap createInputMap(int condition) {
+    protected InputMap createInputMap(int condition) {
         if (condition == JComponent.WHEN_IN_FOCUSED_WINDOW) {
             return new ComponentInputMapUIResource(menuItem);
         }
