@@ -5,6 +5,8 @@
  */
 package com.jidesoft.utils;
 
+import java.awt.*;
+import java.lang.reflect.Field;
 import java.util.Locale;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -90,13 +92,12 @@ final public class SystemInfo {
      */
     private static boolean _isSolaris = false;
 
-    private static JavaVersion _currentVersion;
-
     /**
-     * Make sure the constructor can never be called.
+     * Variable for whether or not we're on *BSD.
      */
-    private SystemInfo() {
-    }
+    private static boolean _isBSD = false;
+
+    private static JavaVersion _currentVersion;
 
     /**
      * Initialize the settings statically.
@@ -142,6 +143,7 @@ final public class SystemInfo {
         }
         if (_isWindows) _supportsTray = true;
         _isSolaris = (os.indexOf("Solaris") != -1) || (os.indexOf("SunOS") != -1);
+        _isBSD = os.endsWith("BSD");
         _isLinux = os.indexOf("Linux") != -1;
         if (os.startsWith("Mac OS")) {
             if (os.endsWith("X")) {
@@ -153,6 +155,12 @@ final public class SystemInfo {
         }
     }
 
+    /**
+     * Make sure the constructor can never be called.
+     */
+    private SystemInfo() {
+    }
+
     /**
      * Returns the version of java we're using.
      *
@@ -358,7 +366,7 @@ final public class SystemInfo {
      * Returns whether or not the os is any Mac os.
      *
      * @return <tt>true</tt> if the application is running on Mac OSX or any previous mac version, <tt>false</tt>
-     *         otherwise.
+     * otherwise.
      */
     public static boolean isAnyMac() {
         return _isMacClassic || _isMacOSX;
@@ -383,13 +391,22 @@ final public class SystemInfo {
     }
 
     /**
-     * Returns whether or not the os is some version of Unix, defined here as only Solaris or Linux.
+     * Returns whether or not the os is *BSD.
      *
-     * @return <tt>true</tt> if the application is running on a type of UNIX such as Linux or Solaris, <tt>false</tt>
-     *         otherwise.
+     * @return <tt>true</tt> if the application is running on *BSD, <tt>false</tt> otherwise.
+     */
+    public static boolean isBSD() {
+        return _isBSD;
+    }
+
+    /**
+     * Returns whether or not the os is some version of Unix, defined here as only Solaris, Linux or *BSD.
+     *
+     * @return <tt>true</tt> if the application is running on a type of UNIX such as Linux, Solaris or *BSD, <tt>false</tt>
+     * otherwise.
      */
     public static boolean isUnix() {
-        return _isLinux || _isSolaris;
+        return _isLinux || _isSolaris || _isBSD;
     }
 
     private static void checkJdkVersion() {
@@ -489,6 +506,16 @@ final public class SystemInfo {
         return _currentVersion.compareVersion(1.7, 0, 0) >= 0;
     }
 
+    /**
+     * Returns whether or no the JDK version is 1.7u40 and above.
+     *
+     * @return <tt>true</tt> if the application is running on JDK 1.7u40 and above, <tt>false</tt> otherwise.
+     */
+    public static boolean isJdk7u40Above() {
+        checkJdkVersion();
+        return _currentVersion.compareVersion(1.7, 0, 40) >= 0;
+    }
+
     /**
      * Returns whether or no the JDK version is 1.8 and above.
      *
@@ -566,6 +593,30 @@ final public class SystemInfo {
                 || locale.equals(Locale.KOREAN);
     }
 
+    public static int getDisplayScale() {
+        if (GraphicsEnvironment.isHeadless()) {
+            return 1;
+        }
+
+        if (isJdk7u40Above()) {
+            GraphicsEnvironment graphicsEnvironment = GraphicsEnvironment.getLocalGraphicsEnvironment();
+            GraphicsDevice device = graphicsEnvironment.getDefaultScreenDevice();
+            try {
+                Field field = device.getClass().getDeclaredField("scale");
+                if (field != null) {
+                    field.setAccessible(true);
+                    Object scale = field.get(device);
+                    if (scale instanceof Integer) {
+                        return (Integer) scale;
+                    }
+                }
+            }
+            catch (Exception ignore) {
+            }
+        }
+        return 1;
+    }
+
     public static class JavaVersion {
         /**
          * For example: 1.6.0_12: Group 1 = major version (1.6) Group 3 = minor version (0) Group 5 = build number (12)
@@ -655,4 +706,5 @@ final public class SystemInfo {
             return _patch;
         }
     }
+
 }
